API Reference
=============

This section provides a detailed reference for the BCRA API Connector's classes and methods.

API Reference
=============

This section provides a detailed reference for the BCRA API Connector's classes and methods, automatically generated from the source code.

BCRAConnector
-------------

.. automodule:: src.bcra_connector.bcra_connector
   :members:
   :undoc-members:
   :show-inheritance:

Principales Variables (Monetarias v4.0)
---------------------------------------

.. automodule:: src.bcra_connector.principales_variables.principales_variables
   :members:
   :undoc-members:
   :show-inheritance:

Cheques
-------

.. automodule:: src.bcra_connector.cheques.cheques
   :members:
   :undoc-members:
   :show-inheritance:

Estadísticas Cambiarias
-----------------------

.. automodule:: src.bcra_connector.estadisticas_cambiarias.estadisticas_cambiarias
   :members:
   :undoc-members:
   :show-inheritance:

Rate Limiter
------------

.. automodule:: src.bcra_connector.rate_limiter
   :members:
   :undoc-members:
   :show-inheritance:

Timeout Config
--------------

.. automodule:: src.bcra_connector.timeout_config
   :members:
   :undoc-members:
   :show-inheritance:
